@@ -4,6 +4,7 @@ from typing import Dict, Iterator, List
 
 from more_itertools import collapse, intersperse, mark_ends
 
+from jubeatools.info import __repository_url__, __version__
 from jubeatools.song import (
     BeatsTime,
     Chart,
@@ -13,7 +14,6 @@ from jubeatools.song import (
     TapNote,
     Timing,
 )
-from jubeatools.version import __version__
 
 from ..dump_tools import (
     BEATS_TIME_TO_SYMBOL,
@@ -143,7 +143,7 @@ def _dump_mono_column_chart(
     # Actual output to file
     file = StringIO()
     file.write(f"// Converted using jubeatools {__version__}\n")
-    file.write("// https://github.com/Stepland/jubeatools\n\n")
+    file.write(f"// {__repository_url__}\n\n")
     for _, section in sections.items():
         file.write(section.render(circle_free) + "\n")
 
